@@ -38,48 +38,24 @@ using Banshee.Gui;
 
 namespace Banshee.Collection.Gui
 {
-    public class AlbumListView : ListView<AlbumInfo>
+    public class AlbumListView : TrackFilterListView<AlbumInfo>
     {
-        private ColumnController column_controller;
-        
         public AlbumListView () : base ()
         {
             ColumnCellAlbum renderer = new ColumnCellAlbum ();
-            
-            column_controller = new ColumnController ();
             column_controller.Add (new Column ("Album", renderer, 1.0));
             ColumnController = column_controller;
             
             RowHeightProvider = renderer.ComputeRowHeight;
-            
-            RowActivated += delegate {
-                ServiceManager.PlaybackController.Source = (ServiceManager.SourceManager.ActiveSource 
-                    as Banshee.Sources.ITrackModelSource);
-                ServiceManager.PlaybackController.Next ();
-            };
-            
-            ServiceManager.PlayerEngine.EventChanged += OnPlayerEngineEventChanged;
-        }
 
-        protected override bool OnFocusInEvent(Gdk.EventFocus evnt)
-        {
-            ServiceManager.Get<InterfaceActionService> ().TrackActions.SuppressSelectActions ();
-            return base.OnFocusInEvent(evnt);
+            ServiceManager.PlayerEngine.ConnectEvent (OnPlayerEvent, PlayerEvent.TrackInfoUpdated);
         }
         
-        protected override bool OnFocusOutEvent(Gdk.EventFocus evnt)
+        private void OnPlayerEvent (PlayerEventArgs args)
         {
-            ServiceManager.Get<InterfaceActionService> ().TrackActions.UnsuppressSelectActions ();
-            return base.OnFocusOutEvent(evnt);
-        }
-        
-        private void OnPlayerEngineEventChanged (object o, PlayerEngineEventArgs args)
-        {
-            if (args.Event == PlayerEngineEvent.TrackInfoUpdated) {
-                // TODO: a) Figure out if the track that changed is actually in view
-                //       b) xfade the artwork if it is, that'd be slick
-                QueueDraw ();
-            }
+            // TODO: a) Figure out if the track that changed is actually in view
+            //       b) xfade the artwork if it is, that'd be slick
+            QueueDraw ();
         }
     }
 }
