@@ -86,6 +86,7 @@ namespace Banshee.Podcasting
             feeds_manager.FeedManager.FeedsChanged += OnFeedsChanged;
 
             ServiceManager.PlayerEngine.ConnectEvent (OnPlayerEvent, PlayerEvent.StateChange);
+            ServiceManager.Get<DBusCommandService> ().ArgumentPushed += OnCommandLineArgument;
 
             InitializeInterface ();
         }
@@ -202,6 +203,7 @@ namespace Banshee.Podcasting
             }
             
             ServiceManager.PlayerEngine.DisconnectEvent (OnPlayerEvent);
+            ServiceManager.Get<DBusCommandService> ().ArgumentPushed -= OnCommandLineArgument;
 
             if (download_manager_iface != null) {
                 download_manager_iface.Dispose ();                
@@ -226,6 +228,23 @@ namespace Banshee.Podcasting
             }
         }
         
+        private void OnCommandLineArgument (string uri, object value, bool isFile)
+        {
+            if (!isFile || String.IsNullOrEmpty (uri)) {
+                return;
+            }
+            
+            // Handle podcast URIs
+            if (uri.StartsWith ("feed://")) {
+                string url = String.Format ("http://{0}", uri.Substring (7));
+                Log.DebugFormat ("Subscribing to podcast at {0}", url);
+
+                // TODO replace autodownload w/ actual default preference
+                FeedsManager.Instance.FeedManager.CreateFeed (url, FeedAutoDownload.None);
+                source.NotifyUser ();
+            }
+        }
+        
         private void RefreshArtworkFor (Feed feed)
         {
             if (feed.LastDownloadTime != DateTime.MinValue)
@@ -253,8 +272,13 @@ namespace Banshee.Podcasting
             }
         }
         
+        internal static bool IgnoreItemChanges = false;
+        
         private void OnItemChanged (FeedItem item)
         {
+            if (IgnoreItemChanges)
+                return;
+
             PodcastTrackInfo track = PodcastTrackInfo.GetByItemId (item.DbId);
             if (track != null) {
                 track.SyncWithFeedItem ();
@@ -322,6 +346,7 @@ namespace Banshee.Podcasting
                 PodcastTrackInfo pi = new PodcastTrackInfo (item);
                 pi.PrimarySource = source;
                 pi.Save (true);
+                source.NotifyUser ();
             } else {
                 item.Delete (false);                      
             }
