@@ -309,6 +309,7 @@ namespace Hyena.Data.Gui
         {
             ColumnCell cell = column_cache[column_index].Column.GetCell (0);
             cell.BindListItem (item);
+            ColumnCellDataProvider (cell, item);
             
             if (dragging) {
                 Cairo.Color fill_color = Theme.Colors.GetWidgetColor (GtkColorClass.Base, StateType.Normal);
@@ -372,6 +373,10 @@ namespace Hyena.Data.Gui
             }
         }
         
+        protected virtual void ColumnCellDataProvider (ColumnCell cell, object boundItem)
+        {
+        }
+        
         private bool rules_hint = false;
         public bool RulesHint {
             get { return rules_hint; }
